@@ -6,13 +6,13 @@ from math import log10
 import gzip
 from lxml import etree
 import sqlite3
-from lib.common.sqlite_command import sqlite_select, check_sql_table, init_sql_db_many_table, sqlite_write
+from toolbiox.lib.common.sqlite_command import sqlite_select, check_sql_table, init_sql_db_many_table, sqlite_write
 from collections import OrderedDict
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.util import logging_init
-import lib.common.sqlite_command as sc
-from lib.common.os import mkdir, cmd_run
-from lib.common.math.interval import section
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.util import logging_init
+import toolbiox.lib.common.sqlite_command as sc
+from toolbiox.lib.common.os import mkdir, cmd_run
+from toolbiox.lib.common.math.interval import section
 
 
 class BlastQuery(object):
@@ -144,7 +144,7 @@ def fast_iter(context, func, *args, **kwargs):
 
 
 def outfmt5_complete(input_file):
-    from lib.xuyuxing.base.base_function import cmd_run
+    from toolbiox.lib.xuyuxing.base.base_function import cmd_run
     output = cmd_run('tail -2 %s' % input_file, silence=True)
     if output[0] is True and output[1] == "</BlastOutput>\n\n":
         return True
@@ -620,7 +620,7 @@ def blast_to_sqlite(db_name, bls_file, query_fasta=None, subject_fasta=None, out
         sqlite_write(waitting_hsp, db_name, "hsp", hsp_columns)
         module_log.info("load %d record" % hsp_id)
 
-    from lib.common.util import printer_list
+    from toolbiox.lib.common.util import printer_list
 
     # write query table
     module_log.info("load query table")
@@ -1080,7 +1080,7 @@ if __name__ == '__main__':
     bls_file = '/lustre/home/xuyuxing/Work/Orobanchaceae/Trans/clean_data/Oro/blat/Trinity.bls'
     query_file = '/lustre/home/xuyuxing/Database/Orobanche/annotation/trinity/trinity_output/Trinity.fasta'
 
-    from lib.common.genome.seq_base import read_fasta_by_faidx
+    from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
 
     seq_dict = read_fasta_by_faidx(query_file)
     len_dict = {i:seq_dict[i].len() for i in seq_dict}
