@@ -5,11 +5,11 @@ import matplotlib.patches as mpatches
 import numpy as np
 import math
 from collections import OrderedDict
-from lib.common.genome.genome_feature2 import read_gff_file
+from toolbiox.lib.common.genome.genome_feature2 import read_gff_file
 from interlap import InterLap
-from lib.common.math.bin_and_window import split_sequence_to_bins
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from lib.common.math.interval import merge_intervals, sum_interval_length
+from toolbiox.lib.common.math.bin_and_window import split_sequence_to_bins
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.lib.common.math.interval import merge_intervals, sum_interval_length
 
 
 class CirclePlot(object):
@@ -869,7 +869,7 @@ def get_cds_density(gff_file, TE_gff_file, genome_fasta_file, bin_length=1000000
         te_chr_interlap_dict[chr_id].update(te_chr_dict[chr_id])
 
     # remove overlap with te
-    from lib.common.math.interval import section
+    from toolbiox.lib.common.math.interval import section
 
     cds_density_dict = {}
     for chr_id in chr_interlap_dict:
