@@ -1,10 +1,10 @@
-from lib.common.genome.genome_feature2 import Gene, GeneSet
+from toolbiox.lib.common.genome.genome_feature2 import Gene, GeneSet
 from collections import OrderedDict
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.util import printer_list
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.util import printer_list
 import pandas as pd
-# from lib.common.evolution.tree_operate import get_top_taxon_clade, get_root_by_species, add_clade_name, lookup_by_names, reroot_by_outgroup_clade, collapse_low_support, get_rooted_tree_by_species_tree
-from lib.common.evolution.tree_operate import get_top_taxon_clade
+# from toolbiox.lib.common.evolution.tree_operate import get_top_taxon_clade, get_root_by_species, add_clade_name, lookup_by_names, reroot_by_outgroup_clade, collapse_low_support, get_rooted_tree_by_species_tree
+from toolbiox.lib.common.evolution.tree_operate import get_top_taxon_clade
 from Bio import Phylo
 
 __author__ = 'Yuxing Xu'
@@ -482,8 +482,8 @@ if __name__ == '__main__':
     sp_info_dict = read_species_info(ref_xlsx)
 
     # get orthogroups from a gene tree (and species tree)
-    from lib.common.fileIO import tsv_file_dict_parse
-    from lib.common.evolution.tree_operate import map_node_species_info, add_clade_name, get_rooted_tree_by_species_tree
+    from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+    from toolbiox.lib.common.evolution.tree_operate import map_node_species_info, add_clade_name, get_rooted_tree_by_species_tree
 
     normal_gene_tree_file = "/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/phylogenomics_old/tree/fasttree/OG0002678/tree.resolve.phb"
     species_tree_file = "/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/species.tree.txt"
@@ -513,7 +513,7 @@ if __name__ == '__main__':
         rooted_taxon_gene_tree, species_tree, taxonomy_level=taxonomy_level, conserved_arguments=conserved_arguments)
 
     # get orthogroups from a nhx tree
-    from lib.common.evolution.tree_operate import load_nhx_tree
+    from toolbiox.lib.common.evolution.tree_operate import load_nhx_tree
 
     nhx_file = '/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/phylogenomics/tree/treebest/OG0001138/tree.nhx'
     species_tree_file = "/lustre/home/xuyuxing/Work/Gel/orcWGD_redo/species.tree.txt"
