@@ -1,31 +1,31 @@
-from src.xuyuxing.GenomeTools.WPGmapper import load_map_files, extract_all_evidences
-from api.xuyuxing.file_parser.fileIO import tsv_file_parse
-from lib.common.genome.genome_feature2 import HomoPredictResults
+from toolbiox.src.xuyuxing.GenomeTools.WPGmapper import load_map_files, extract_all_evidences
+from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_parse
+from toolbiox.lib.common.genome.genome_feature2 import HomoPredictResults
 from datetime import datetime
 from collections import Counter
-from lib.common.math.interval import section, merge_intervals, overlap_between_interval_set, \
+from toolbiox.lib.common.math.interval import section, merge_intervals, overlap_between_interval_set, \
     group_by_intervals_with_overlap_threshold, sum_interval_length
-from src.xuyuxing.tools.phytools import PtTree
+from toolbiox.src.xuyuxing.tools.phytools import PtTree
 from Bio import Phylo
 import pickle
 import sqlite3
 import re
 import os
 from interlap import InterLap
-from config import wu_blast_path
+from toolbiox.config import wu_blast_path
 from BCBio import GFF
-from api.xuyuxing.genome.mcl import gene_mcl
-from lib.common.sqlite_command import sqlite_select
-from lib.common.evolution.tree_operate import monophyly
-from lib.common.util import printer_list
-from lib.common.util import logging_init, configure_parser
-from api.common.genome.blast import evalue_to_wvalue
-from lib.common.genome.seq_base import read_fasta_by_faidx, extract_seq_from_sqlite, write_fasta
-from lib.common.fileIO import tsv_file_dict_parse
-from lib.common.os import mkdir, cmd_run, multiprocess_running
-from api.xuyuxing.genome.genblasta import genblasta_run, genblasta_to_genewise, get_HPR_from_genewise_results, gene_to_aa, \
+from toolbiox.api.xuyuxing.genome.mcl import gene_mcl
+from toolbiox.lib.common.sqlite_command import sqlite_select
+from toolbiox.lib.common.evolution.tree_operate import monophyly
+from toolbiox.lib.common.util import printer_list
+from toolbiox.lib.common.util import logging_init, configure_parser
+from toolbiox.api.common.genome.blast import evalue_to_wvalue
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx, extract_seq_from_sqlite, write_fasta
+from toolbiox.lib.common.fileIO import tsv_file_dict_parse
+from toolbiox.lib.common.os import mkdir, cmd_run, multiprocess_running
+from toolbiox.api.xuyuxing.genome.genblasta import genblasta_run, genblasta_to_genewise, get_HPR_from_genewise_results, gene_to_aa, \
     gene_to_cds, query_gene_to_speci
-from api.xuyuxing.comp_genome.orthofinder import OrthoFinderResults, get_species_id_from_gene_id
+from toolbiox.api.xuyuxing.comp_genome.orthofinder import OrthoFinderResults, get_species_id_from_gene_id
 import configparser
 import argparse
 import sys
