@@ -1,7 +1,7 @@
 import re
-from lib.common.genome.seq_base import read_fasta_by_faidx
-from lib.common.genome.genome_feature2 import GenomeFeature, ChrLoci, write_gff_file
-from lib.common.math.interval import merge_intervals
+from toolbiox.lib.common.genome.seq_base import read_fasta_by_faidx
+from toolbiox.lib.common.genome.genome_feature2 import GenomeFeature, ChrLoci, write_gff_file
+from toolbiox.lib.common.math.interval import merge_intervals
 
 def MaskFasta2Gff_main(args):
     seq_dict = read_fasta_by_faidx(args.masked_file)
