@@ -1,14 +1,14 @@
 import os
 from collections import OrderedDict
-from api.xuyuxing.resource.ncbi_genome import build_ncbi_genome_database, md5checksums_checker, ascp_download, wget_download, genome_chooser
-from lib.common.fileIO import read_list_file
+from toolbiox.api.xuyuxing.resource.ncbi_genome import build_ncbi_genome_database, md5checksums_checker, ascp_download, wget_download, genome_chooser
+from toolbiox.lib.common.fileIO import read_list_file
 import re
-from lib.xuyuxing.evolution.taxonomy import build_taxon_database, read_tax_record_dict_db, store_tax_record_into_sqlite
-from lib.xuyuxing.base.common_command import log_print
-from api.xuyuxing.file_parser.fileIO import tsv_file_dict_parse, tsv_file_parse
-from lib.common.os import md5sum_check
+from toolbiox.lib.xuyuxing.evolution.taxonomy import build_taxon_database, read_tax_record_dict_db, store_tax_record_into_sqlite
+from toolbiox.lib.xuyuxing.base.common_command import log_print
+from toolbiox.api.xuyuxing.file_parser.fileIO import tsv_file_dict_parse, tsv_file_parse
+from toolbiox.lib.common.os import md5sum_check
 import time
-from config import taxon_dump
+from toolbiox.config import taxon_dump
 import sys
 from ftplib import FTP
 from retry import retry
